# How to Search Catalysis Data
![Header](ScreenshotCatalysisAppHead-1.png)

This plugin provides a dedicated heterogeneous catalysis app which makes it possible to get a quick overview of related entries, visualize results and search for specific information. The catalysis app of the central NOMAD service can be accessed [here](https://nomad-lab.eu/prod/v1/gui/search/heterogeneouscatalyst).

The app has 3 main components: the filter menu on the left, the dashboard in the center, and the entry list below the dashboard.

## Dashboard
The quick entry to exploring the catalysis data in the NOMAD database is the dashboard. It prominently features the periodic table of the elements indicating the elemental composition of the catalyst sample entries and of the materials tested in catalytic reactions. Furthermore there are windows, so-called "Widgets", displaying the catalytic reactions, reactants and products which were uploaded into NOMAD.
At the bottom there are two default scatterplots which give an idea about the temperature range, feed composition and achived conversions in the catalytic reactions tested.
![image of Catalysis App Dashboard](ScreenshotDashboard.png)

## Filter Menu
The Filter Menu allows to quickly access a number of properties conveniently grouped under the main menu items "Catalyst Materials" and "Reactions" each with further submenu items. Upon clicking one of the menu headings a panel with the properties opens. Each property comes with a window displaying the most common occurances in the database and also a search bar to search for other less common instances. In addition to getting a quick overview of the data in the database, these windows can be used to filter and search specific data entries as well.  

![image of Filter Menu](ScreenshotFilterMenu.png)


## Result Entry List

Below the dashboard there is the search results list, which gives direct access to the individual data entries which fit the applied filter criteria, along with some further key information about the entries.
![image of result entry list](ScreenshotEntrylist.png)

## Custom Search

At the top of the page, there is the searchbar for direct filter and search, as well as buttons to create your own, custom widgets. 


